==> kdepim-addons_18.08.3.orig.tar.xz: kdepim-addons-18.08.3/kmail/editorsendcheckplugins/checkbeforesend/configurewidget/checkbeforesendconfiguredialog.cpp <==
/*
   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "checkbeforesendconfiguredialog.h"
#include "checkbeforesendconfigurewidget.h"
#include <KLocalizedString>

CheckBeforeSendConfigureDialog::CheckBeforeSendConfigureDialog(QWidget *parent)
    : PimCommon::ConfigurePluginDialog(parent)
    , mConfigureWidget(nullptr)
{
    setWindowTitle(i18n("Configure \"Check Before Send Mail\" Plugin"));
    initLayout();
}

CheckBeforeSendConfigureDialog::~CheckBeforeSendConfigureDialog()
{
}

QWidget *CheckBeforeSendConfigureDialog::createLayout()
{
    mConfigureWidget = new CheckBeforeSendConfigureWidget(this);
    return mConfigureWidget;
}

void CheckBeforeSendConfigureDialog::save()
{
    mConfigureWidget->saveSettings();
}

void CheckBeforeSendConfigureDialog::load()
{
    mConfigureWidget->loadSettings();
}

void CheckBeforeSendConfigureDialog::reset()
{
    mConfigureWidget->resetSettings();
}

void CheckBeforeSendConfigureDialog::help()
{
    showHelp(QStringLiteral("kmail2"), QString());
}

==> kdepim-addons_19.12.3.orig.tar.xz: kdepim-addons-19.12.3/kmail/editorsendcheckplugins/checkbeforesend/configurewidget/checkbeforesendconfiguredialog.cpp <==
/*
   Copyright (C) 2016-2019 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "checkbeforesendconfiguredialog.h"
#include "checkbeforesendconfigurewidget.h"
#include <KLocalizedString>

CheckBeforeSendConfigureDialog::CheckBeforeSendConfigureDialog(QWidget *parent)
    : PimCommon::ConfigurePluginDialog(parent)
    , mConfigureWidget(nullptr)
{
    setWindowTitle(i18n("Configure \"Check Before Send Mail\" Plugin"));
    initLayout();
}

CheckBeforeSendConfigureDialog::~CheckBeforeSendConfigureDialog()
{
}

QWidget *CheckBeforeSendConfigureDialog::createLayout()
{
    mConfigureWidget = new CheckBeforeSendConfigureWidget(this);
    return mConfigureWidget;
}

void CheckBeforeSendConfigureDialog::save()
{
    mConfigureWidget->saveSettings();
}

void CheckBeforeSendConfigureDialog::load()
{
    mConfigureWidget->loadSettings();
}

void CheckBeforeSendConfigureDialog::reset()
{
    mConfigureWidget->resetSettings();
}

void CheckBeforeSendConfigureDialog::help()
{
    showHelp(QStringLiteral("kmail2"), mConfigureWidget->helpAnchor());
}
